// Creates a namespace to be used for scoping variables and classes
Ext.namespace('GO.testmodule');

/*
 * This is the constructor of our PresidentDialog
 */
GO.testmodule.PresidentDialog = function(config){	
	
	if(!config)
	{
		config={};
	}
	
	this.buildForm();
	
	var focusFirstField = function(){
		this.presidentPanel.items.items[0].focus();
	};
	
	config.maximizable=true;
	config.layout='fit';
	config.modal=false;
	config.resizable=false;
	config.width=300;
	config.height=250;
	config.closeAction='hide';
	config.title= 'President Dialog';					
	config.items= this.formPanel;
	config.focus= focusFirstField.createDelegate(this);
	config.buttons=[{
			text: GO.lang['cmdOk'],
			handler: function(){
				this.submitForm(true);
			},
			scope: this
		},{
			text: GO.lang['cmdApply'],
			handler: function(){
				this.submitForm();
			},
			scope:this
		},{
			text: GO.lang['cmdClose'],
			handler: function(){
				this.hide();
			},
			scope:this
		}					
	];

	/*
	 * explicitly call the superclass constructor
	 */
	GO.testmodule.PresidentDialog.superclass.constructor.call(this, config);
	
	this.addEvents({'save' : true});	

}

/*
 * Extend the base class
 */
Ext.extend(GO.testmodule.PresidentDialog, Ext.Window,{
	
	show : function (president_id) {

		if(!this.rendered)
			this.render(Ext.getBody());
		
		if(!president_id)
		{
			president_id=0;			
		}
			
		this.setPresidentID(president_id);
		
		if(this.president_id>0)
		{
			this.formPanel.load({
				url : GO.settings.modules.testmodule.url+'json.php',
				
				success:function(form, action)
				{
					this.partyName.setRemoteText(action.result.data.partyName);
					GO.testmodule.PresidentDialog.superclass.show.call(this);
				},
				failure:function(form, action)
				{
					Ext.Msg.alert(GO.lang['strError'], action.result.feedback)
				},
				scope: this		
			});
		} else 
		{	
			this.formPanel.form.reset();
	
			GO.testmodule.PresidentDialog.superclass.show.call(this);
		}
	},
	
	setPresidentID : function(president_id)
	{
		this.formPanel.form.baseParams['president_id']=president_id;
		this.president_id=president_id;
	},
	
	submitForm : function(hide){
		this.formPanel.form.submit(
		{
			url:GO.settings.modules.testmodule.url+'action.php',
			params: {'task' : 'save_president'},
			waitMsg:GO.lang['waitMsgSave'],
			success:function(form, action){
				this.fireEvent('save', this);
				
				if(hide)
				{
					this.hide();	
				}else
				{			
					if(action.result.president_id)
					{
						this.setPresidentID(action.result.president_id);
									
					}
				}											
			},		
			failure: function(form, action) {
				if(action.failureType == 'client')
				{					
					Ext.MessageBox.alert(GO.lang['strError'], GO.lang['strErrorsInForm']);			
				} else {
					Ext.MessageBox.alert(GO.lang['strError'], action.result.feedback);
				}
			},
			scope: this
		});
		
	},
	
	buildForm : function () {
		
		this.presidentPanel = new Ext.Panel({
			border: false,
			cls:'go-form-panel',waitMsgTarget:true,
			layout:'form',
			autoScroll:true,
			items: [{   
				name: 'firstname',
				xtype: 'textfield',
				fieldLabel: 'First Name',
				anchor: '100%',
				allowBlank:false,
				maskRe: /([a-zA-Z0-9\s]+)$/
			},{
				name: 'lastname',
				xtype: 'textfield',
				fieldLabel: 'Last Name',
				anchor: '100%',
				allowBlank:false,
				maskRe: /([a-zA-Z0-9\s]+)$/
			},this.partyName = new GO.form.ComboBox({
				hiddenName:'IDparty',
				fieldLabel:'Party',
				anchor:'100%',			     
				store: new GO.data.JsonStore({
					url: GO.settings.modules.testmodule.url+ 'json.php',
					baseParams: {						    	
						task: 'parties'
					},
					root:'results',
					id:'partyName',
					totalProperty:'total',
					fields: ['IDparty', 'partyName'],
					remoteSort: true
				}),
				valueField:'IDparty',
				displayField:'partyName',
				mode: 'remote',
				triggerAction: 'all',
				forceSelection: true,
				selectOnFocus:true,
				allowBlank: false
			}),this.tookoffice = new Ext.form.DateField({
				name: 'tookoffice',
				fieldLabel: 'Entering Office',
				format: GO.settings['date_format'],
				allowBlank: false,
				anchor:'100%'
			}),this.leftoffice = new Ext.form.DateField({
				name: 'leftoffice',
				fieldLabel: 'Leaving Office',
				format: GO.settings['date_format'],			    
				allowBlank: false,
				anchor: '100%'
			}),this.income = new GO.form.NumberField({
				name: 'income',
				fieldLabel: 'Income',
				allowBlank: false,
				allowDecimals: true,
				allowNegative: false
			})]
		});


		var items = [this.presidentPanel];
	    
		this.formPanel = new Ext.form.FormPanel({
			waitMsgTarget:true,
			url: GO.settings.modules.testmodule.url+'json.php',
			border: false,
			baseParams: {task: 'president'},
			items: items
		});	    
	}
	
});
	