// Creates a namespace to be used for scoping variables and classes
Ext.namespace('GO.testmodule');

/*
 * This is the constructor of our PresidentsGrid
 */
GO.testmodule.PresidentsGrid = function(config){

	if(!config)
	{
		config = {};
	}

	config.title = 'Presidents of the USA';
	config.layout='fit';
	config.autoScroll=true;
	config.split=true;
	config.store = new GO.data.JsonStore({
		/*
		 * Here we store our remotely-loaded JSON data from json.php?task=presidents
		 */
		url: GO.settings.modules.testmodule.url+ 'json.php',
		baseParams: {
		    task: 'presidents'
		},
		root: 'results',
		id: 'id',
		totalProperty:'total',
		fields: ['id','firstname','lastname','partyid','partyName','tookoffice','leftoffice','income'],
		remoteSort: true
	});	
	
	/*
	 * ColumnModel used by our PresidentsGrid
	 */
	var PresidentsColumnModel = new Ext.grid.ColumnModel(
		[{
			header: '#',
			readOnly: true,
			dataIndex: 'id',
			renderer: function(value, cell){ 
				cell.css = "readonlycell";
				return value;
			},
			width: 50
		},{
			header: 'First Name',
			dataIndex: 'firstname',
			width: 120
		},{
			header: 'Last Name',
			dataIndex: 'lastname',
			width: 120
		},{
			header: 'ID party',
			readOnly: true,
			dataIndex: 'partyid',
			width: 50,
			hidden: true
		},{
			header: 'Party',
			dataIndex: 'partyName',    
			width: 120,
		},{
			header: 'Took Office',
			dataIndex: 'tookoffice',
			width: 80
		},{
			header: 'Left Office',
			dataIndex: 'leftoffice',
			width: 80
		},{
			header: "Income",
			dataIndex: 'income',
			width: 120,
			renderer: function(value, cell){ 
				var str = '';
			 	if(value > 1000000){
			    	str = "<span style='color:#336600;'>$ " + value + "</span>";
			 	} else if (value > 100000){
			    	str = "<span style='color:#FF9900;'>$ " + value + "</span>";
			 	} else {
			    	str = "<span style='color:#CC0000;'>$ " + value + "</span>";
				}
				return str; 
			}
		}]
	);
	PresidentsColumnModel.defaultSortable= true;
	config.cm=PresidentsColumnModel;

	config.view=new Ext.grid.GridView({
		emptyText: GO.lang['strNoItems']
	});

	config.sm=new Ext.grid.RowSelectionModel();
	config.loadMask=true;
	
	/* config.paging is an added functionality by Group-Office
	 * which makes it very easy to add a PagingToolbar.	
	 */ 
	config.paging=true,	
		

	/*
	 * explicitly call the superclass constructor
	 */
	GO.testmodule.PresidentsGrid.superclass.constructor.call(this, config);	
				
};
	
/*
 * Extend the base class
 */
Ext.extend(GO.testmodule.PresidentsGrid, GO.grid.GridPanel,{

	loaded : false,

	afterRender : function()
	{
		GO.testmodule.PresidentsGrid.superclass.afterRender.call(this);
	
		if(this.isVisible())
		{
			this.onGridShow();
		}
	},

	onGridShow : function(){
		if(!this.loaded && this.rendered)
		{
			this.store.load();
			this.loaded=true;
		}
	},
    
});


	