<?php

/*
* Each module class file extends the db class
*/
class presidents extends db {

	/**
	 * Add a President
	 *
	 * @param Array $president Associative array of record fields
	 *
	 * @access public
	 * @return int New record ID created
	 */
	function add_president($president)
	{
		$president['id']=$this->nextid('tm_presidents');
		if($this->insert_row('tm_presidents', $president))
		{
			return $president['id'];
		}
		return false;
	}

	/**
	 * Update a President
	 *
	 * @param Array $president Associative array of record fields
	 *
	 * @access public
	 * @return bool True on success
	 */
	function update_president($president)
	{
		return $this->update_row('tm_presidents', 'id', $president);
	}

	/**
	 * Delete a President
	 *
	 * @param Int $president_id ID of the president
	 *
	 * @access public
	 * @return bool True on success
	 */
	function delete_president($president_id)
	{
		return $this->query("DELETE FROM tm_presidents WHERE id=?", 'i', $president_id);
	}

	/**
	 * Gets a President record
	 *
	 * @param Int $president_id ID of the president
	 * 
	 * @access public
	 * @return Array Record properties
	 */
	function get_president($president_id)
	{
		$this->query("SELECT * FROM tm_presidents pr, tm_parties pa WHERE pr.IDparty = pa.IDparty AND pr.id=?", 'i', $president_id);
		return $this->next_record();
	}
	
	/**
	 * Gets all Presidents
	 *
	 * @param Int $start First record of the total record set to return
	 * @param Int $offset Number of records to return
	 * @param String $sortfield The field to sort on
	 * @param String $sortorder The sort order
	 *
	 * @access public
	 * @return Int Number of records found
	 */
	function get_presidents($sortfield='id', $sortorder='ASC', $start=0, $offset=0)
	{
		$sql = "SELECT ";
		if($offset>0)
		{
			$sql .= "SQL_CALC_FOUND_ROWS ";
		}
		$sql .= "* FROM tm_presidents pr, tm_parties pa WHERE pr.IDparty = pa.IDparty"
				." ORDER BY ".$this->escape($sortfield.' '.$sortorder);
		if($offset>0)
		{
			$sql .= " LIMIT ".intval($start).",".intval($offset);
		}

		return $this->query($sql);	
	}

 	/**
	 * Gets all Parties
	 *
	 * @param Int $start First record of the total record set to return
	 * @param Int $offset Number of records to return
	 * @param String $sortfield The field to sort on
	 * @param String $sortorder The sort order
	 *
	 * @access public
	 * @return Int Number of records found
	 */
	function get_parties($sortfield='IDparty', $sortorder='ASC', $start=0, $offset=0, $partyName='')
	{
		$sql = "SELECT ";
		if($offset>0)
		{
			$sql .= "SQL_CALC_FOUND_ROWS ";
		}
		$sql .= "* FROM tm_parties";
		$types='';
		$params=array();
		if(!empty($partyName))
		{
			$sql .= " WHERE partyName=?";
			$types .= 's';
 			$params[]=$query;
		}
		$sql .= " ORDER BY ".$this->escape($sortfield.' '.$sortorder);
		if($offset>0)
		{
			$sql .= " LIMIT ".intval($start).",".intval($offset);
		}
		return $this->query($sql, $types, $params);
	}

}
